#!/usr/bin/env python
# $Id$

import sys
try:
    from pyme import core, callbacks
    from pyme.constants.sig import mode
except ImportError:
    sys.stderr.write('Please install the pyme python gnupg interface ')
    sys.stderr.write('from http://pyme.sourceforge.net/\n')
    sys.exit(1)

class GnupgSign:
    def __init__(self, signer, message):
        self.plaintext = core.Data(message)
        self.signedtext = core.Data()
        self.signer = signer
        self.context = core.Context()
        self.context.signers_clear()
        for sigkey in [x for x in self.context.op_keylist_all(self.signer, 1)]:
            if sigkey.can_sign:
                self.context.signers_add(sigkey)
        if not self.context.signers_enum(0):
            print "No secret %s's keys suitable for signing!" % self.signer
            sys.exit(1)

    def set_passphrase(self):
        self.context.set_passphrase_cb(callbacks.passphrase_stdin, 'for signing')

    def sign(self):
        self.context.op_sign(self.plaintext, self.signedtext, mode.CLEAR)
        self.signedtext.seek(0,0)
        return self.signedtext.read()

if __name__ == '__main__':
    plaintext = "This is a test"
    msg = GnupgSign('test@email.com', plaintext)
    msg.set_passphrase()
    print msg.sign()

# vim:syntax=python
# vim:sw=4:softtabstop=4:expandtab
